Classes
=======

CFLARE
~~~~~~

.. autoclass:: cellrank.tl.CFLARE
    :members:

GPCCA
~~~~~
.. autoclass:: cellrank.tl.GPCCA
    :members:

Models
~~~~~~

SKLearnModel
------------

.. autoclass:: cellrank.ul.models.SKLearnModel
    :members:

GamMGCVModel
------------

.. autoclass:: cellrank.ul.models.GamMGCVModel
    :members:

Kernels
~~~~~~~

Velocity Kernel
---------------

.. autoclass:: cellrank.tl.kernels.VelocityKernel
    :members:

Connectivity Kernel
-------------------

.. autoclass:: cellrank.tl.kernels.ConnectivityKernel
    :members:

Palantir Kernel
---------------

.. autoclass:: cellrank.tl.kernels.PalantirKernel
    :members:

Precomputed Kernel
------------------

.. autoclass:: cellrank.tl.kernels.PrecomputedKernel
    :members:

Base Classes
~~~~~~~~~~~~

Kernel
------

.. autoclass:: cellrank.tl.kernels.Kernel
    :members:

Model
-----

.. autoclass:: cellrank.ul.models.Model
    :members:

Lineage
-------

.. autoclass:: cellrank.tl.Lineage
    :members:
